#!/usr/bin/gnuplot

# disk_sfd.plt
# Number of planetesimal disk bodies larger that a given size.
# Vokrouhlicky, Nesvorny & Levison (2008)

q1 = 5.0		# slopes of the SFD
q2 = 2.5
D0 = 50.e3		# m

rho = 1300.		# kg/m^3
M_E = 5.97e24		# kg
M_disk = 35.*M_E	# kg

M0(D0) = pi/6.*rho*D0**3

D1(q1,q2,D0,M_disk) = D0 * ( (q1-4)*(4-q2)/((q1-1)*(q1-q2)) * M_disk/M0(D0) )**(1./(q1-1))

N_gt_D(D,q1,q2,D0,M_disk) = (q1-1)/(q2-1) * (D1(q1,q2,D0,M_disk)/D0)**(q1-1) * (D0/D)**(q2-1) - (q1-q2)/(q2-1) * (D1(q1,q2,D0,M_disk)/D0)**(q1-1)

print "q1 = ", q1
print "q2 = ", q2
print "D0 = ", D0, " m = ", D0/1.e3, " km"
print "M_disk = ", M_disk, " kg = ", M_disk/M_E, " M_E"
print "M0 = ", M0(D0), " kg = ", M0(D0)/M_E, " M_E"
print "D1 = ", D1(q1,q2,D0,M_disk), " m = ", D1(q1,q2,D0,M_disk)/1.e3, " km"

V_imp = 10.e3	# m/s; average impact velocity
Q_100km = 1.e5  # J/kg; from scaling law for D = 100 km bodies
D_target = 100. # km; target diameter

Q_star = Q_100km * (D_target/100.)**2			# in gravity regime
d_disrupt = (2*Q_star/V_imp**2)**(1./3.) * D_target     # projectile size needed (Bottke etal 2006)
D = d_disrupt * 1e3

print "\nD_target = ", D_target, " km"
print "Q_star = ", Q_star, " J/kg = ", Q_star/1e5, " 10^5 J/kg"
print "d_disrupt = ", d_disrupt, " km"
print "D = ", D, " m = ", D/1.e3, " km"
print "N(>100km) = ", N_gt_D(D,q1,q2,D0,M_disk), " = ", N_gt_D(D,q1,q2,D0,M_disk)/1.e9, " * 10^9"

D_target = 200. # km; target diameter
Q_star = Q_100km * (D_target/100.)**2			# in gravity regime
d_disrupt = (2*Q_star/V_imp**2)**(1./3.) * D_target     # projectile size needed (Bottke etal 2006)
D = d_disrupt * 1e3

print "\nD_target = ", D_target, " km"
print "Q_star = ", Q_star, " J/kg = ", Q_star/1e5, " 10^5 J/kg"
print "d_disrupt = ", d_disrupt, " km"
print "D = ", D, " m = ", D/1.e3, " km"
print "N(>200km) = ", N_gt_D(D,q1,q2,D0,M_disk), " = ", N_gt_D(D,q1,q2,D0,M_disk)/1.e9, " * 10^9"

########################################################################

#set label sprintf("q1 = %.3f", q1) at graph 0.9, graph 0.90 right
#set label sprintf("q2 = %.3f", q2) at graph 0.9, graph 0.85 right
#set label sprintf("D0 = %.3f", D0) at graph 0.9, graph 0.80 right
#set arrow from D0/1.e3,graph 1 to D0/1.e3,graph 0

set xl "D / km"
set yl "N(>D) <- valid only for D > D0"

set xr [1.:200.]
set yr [1.e7:5e12]
set logscale xy
set mytics 10
set samples 1000

p N_gt_D(x*1.e3, 5.0, 2.5, 50.e3, 35.*M_E) lw 6,\
  N_gt_D(x*1.e3, 5.0, 2.0, 50.e3, 35.*M_E) lw 5,\
  N_gt_D(x*1.e3, 5.0, 1.5, 50.e3, 35.*M_E) lw 4,\
  N_gt_D(x*1.e3, 5.0, 1.1, 50.e3, 35.*M_E) lw 3,\
  N_gt_D(x*1.e3, 4.5, 2.5, 50.e3, 35.*M_E) lw 2,\
  N_gt_D(x*1.e3, 5.0, 2.5, 70.e3, 35.*M_E) lw 1,\
  N_gt_D(x*1.e3, 5.0, 0.0, 70.e3, 10.*M_E) lw 0.5,\
  N_gt_D(x*1.e3, 5.0, 2.5, 150.e3, 35.*M_E) lw 0.5,\
  1.e8 * (x/100.)**-2,\
  "<awk '(NR>1)' sfd2.dat | ./hc_sfd.awk" w lp
pa -1

set term post eps enh color solid "Helvetica" 18
set out "disk_sfd.eps"
rep


