#!/usr/bin/gnuplot

set term post eps enh color solid "Helvetica" 18
set out "sfd_0010.eps"

set xl "diameter {/Helvetica-Oblique D} / km"
set yl "number of asteroids {/Helvetica-Oblique N}(>{/Helvetica-Oblique D})" offset +1

set xr [0.04:1000]
y1=0.8
y2=1.e10
set yr [y1:y2]
set logscale xy
set mxtics 10
set ytics 10
set mytics 10
set grid ytics
set key width -10 font "Helvetica,14"

print "t = 10.00"
set nolabel
#set label "t = 10.00 My" at graph 0.95, graph 1-0.275 right
set title "{/Helvetica-Oblique t} = 10.00 My"

set style line 5 lt 9 lw 2 pt 1		# observed MB
set style line 3 lt 8 lw 2 pt 1		# initial MB
set style line 1 lt 1 lw 2 pt 1		# evolved MB
set style line 4 lt 5 lw 2 pt 1		# initial comets
set style line 2 lt 3 lw 2 pt 1		# evolved comets
set style line 6 lt 7 lw 2 pt 1		# evolved family

f(x,D0,N,alpha) = N*(x/D0)**alpha

p \
  "MB.dat_hc" u 1:2 t "observed MB" w l ls 5,\
  "<./hc_sfd.awk sfd1.dat_EDITED" u 1:2 t "initial MB" w l  ls 3,\
  "<./hc_sfd.awk sfd2.dat" u 1:2 t "initial comets" w l  ls 4,\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*/tmp/0010.out | ./hc.awk" u 1:2 t "evolved MB" w lp ls 1,\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*/tmp/0010.out | ./hc.awk" u 1:2 t "evolved comets" w lp ls 2,\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*/tmp/0010.out | ./hc.awk" u 1:($2/1.e4) t "synthetic Zhongguos" w l ls 6,\
  f(x,10.,1,-2.5) t "slopes from -2.5 to -4.5" lt 9,\
  f(x,10.,1,-3.0) not lt 9,\
  f(x,10.,1,-3.5) not lt 9,\
  f(x,10.,1,-4.0) not lt 9,\
  f(x,10.,1,-4.5) not lt 9

q
  "../001/tmp/0010.out_hc" u 1:($2/1.e4) t "synthetic Zhongguo at 10 Myr" w l lw 3,\


